@@ -2,7 +2,6 @@ from typing import List
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 from starlette.middleware import Middleware
-from starlette.middleware.base import BaseHTTPMiddleware
 
 
 def register_middleware(app: FastAPI, middlewares: List[Middleware] = None):
@@ -16,7 +15,6 @@ def register_middleware(app: FastAPI, middlewares: List[Middleware] = None):
 
     if middlewares:
         for middleware in middlewares:
-            if app.middleware_stack is not None:  # pragma: no cover
-                raise RuntimeError("Cannot add middleware after an application has started")
+            # if app.middleware_stack is not None:  # pragma: no cover
+            #     raise RuntimeError("Cannot add middleware after an application has started")
             app.user_middleware.insert(0, middleware)
-            # app.add_middleware(middleware)
